@@ -578,7 +578,7 @@ class DataPlate:
     write_to_s3_parquet.__doc__ = wr.s3.to_parquet.__doc__.replace('awswrangler','dataplate')
 
 
-    def run_notebook(self, notebook_file_path, instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= []):
+    def run_notebook(self, notebook_file_path, instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
         """Run a notebook in SageMaker Processing producing a new output notebook.
         Args:
             notebook (str): The notebook file path.
@@ -589,6 +589,7 @@ class DataPlate:
             max_time_limit_minutes : maximum minutes to run before force stop
             securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
             subnets : a list of subnets of aws for the processing job to communicate with
+            role : a role ARN to run the notebook, the default is the Dataplate service role (cross rols in case of Sass)
         Returns:
             The name of the processing job created to run the notebook.
         """
@@ -614,10 +615,11 @@ class DataPlate:
                 params['parameters'] = parameters
             if max_time_limit_minutes:
                 params['timelimit_minutes'] = max_time_limit_minutes
-            params['SecurityGroupIds'] = securityGroupIds
-            params['Subnets'] = subnets
+            params['SecurityGroupIds'] =  json.dumps(securityGroupIds)#','.join(['"%s"' % w for w in securityGroupIds])
+            params['Subnets'] = json.dumps(subnets)#','.join(['"%s"' % w for w in subnets])
             params['notebook_name'] = notebook_name if notebook_name else ""
-
+            if role:
+                params['role'] = role
 
             headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
 
@@ -1144,7 +1146,7 @@ class DataPlate:
 
 
 
-    def schedule_notebook(self, notebook_file_path, rule_name = None, schedule = None, instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= []):
+    def schedule_notebook(self, notebook_file_path, rule_name = None, schedule = None, instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
         """Create a schedule for running a notebook in SageMaker Processing.
 
             Creates a CloudWatch Event rule to invoke the installed Lambda either on the provided schedule or in response
@@ -1169,6 +1171,7 @@ class DataPlate:
                 max_time_limit_minutes : maximum minutes to run before force stop
                 securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
                 subnets : a list of subnets of aws for the processing job to communicate with
+                role : a role ARN to run the notebook, the default is the Dataplate service role (cross rols in case of Sass)
             """
         try:
             if not notebook_file_path or not os.path.isfile(notebook_file_path) or not notebook_file_path.endswith('.ipynb'):
@@ -1192,8 +1195,8 @@ class DataPlate:
                 params['parameters'] = parameters
             if max_time_limit_minutes:
                 params['timelimit_minutes'] = max_time_limit_minutes
-            params['SecurityGroupIds'] = securityGroupIds
-            params['Subnets'] = subnets
+            params['SecurityGroupIds'] = ",".join(securityGroupIds)
+            params['Subnets'] = ",".join(subnets)
             params['notebook_name'] = notebook_name if notebook_name else ""
             if not rule_name:
                 raise Error(f'rule_name is required')
@@ -1201,6 +1204,8 @@ class DataPlate:
                 raise Error(f'schedule is required, see https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-create-rule-schedule.html#eb-cron-expressions')
             params['rule_name'] = rule_name
             params['schedule'] = schedule
+            if role:
+                params['role'] = role
 
             headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
 
